==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EmailServerListResponse.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EmailServerResponse;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailServerListResponse
 */
@JsonPropertyOrder({ EmailServerListResponse.JSON_PROPERTY_EMAIL_SERVERS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class EmailServerListResponse implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EMAIL_SERVERS = "email-servers";
    private List<EmailServerResponse> emailServers = null;

    public EmailServerListResponse() {
    }

    public EmailServerListResponse emailServers(List<EmailServerResponse> emailServers) {

        this.emailServers = emailServers;
        return this;
    }

    public EmailServerListResponse addemailServersItem(EmailServerResponse emailServersItem) {
        if (this.emailServers == null) {
            this.emailServers = new ArrayList<>();
        }
        this.emailServers.add(emailServersItem);
        return this;
    }

    /**
     * Get emailServers
     *
     * @return emailServers
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EMAIL_SERVERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<EmailServerResponse> getEmailServers() {
        return emailServers;
    }

    @JsonProperty(JSON_PROPERTY_EMAIL_SERVERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmailServers(List<EmailServerResponse> emailServers) {
        this.emailServers = emailServers;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailServerListResponse emailServerListResponse = (EmailServerListResponse) o;
        return Objects.equals(this.emailServers, emailServerListResponse.emailServers);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(emailServers);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailServerListResponse {\n");
        sb.append("    emailServers: ").append(toIndentedString(emailServers)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EmailServerListResponse.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EmailServerResponse;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailServerListResponse
 */
@JsonPropertyOrder({ EmailServerListResponse.JSON_PROPERTY_EMAIL_SERVERS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class EmailServerListResponse implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_EMAIL_SERVERS = "email-servers";
    private List<EmailServerResponse> emailServers = null;

    public EmailServerListResponse() {
    }

    public EmailServerListResponse emailServers(List<EmailServerResponse> emailServers) {

        this.emailServers = emailServers;
        return this;
    }

    public EmailServerListResponse addemailServersItem(EmailServerResponse emailServersItem) {
        if (this.emailServers == null) {
            this.emailServers = new ArrayList<>();
        }
        this.emailServers.add(emailServersItem);
        return this;
    }

    /**
     * Get emailServers
     *
     * @return emailServers
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EMAIL_SERVERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<EmailServerResponse> getEmailServers() {
        return emailServers;
    }

    @JsonProperty(JSON_PROPERTY_EMAIL_SERVERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmailServers(List<EmailServerResponse> emailServers) {
        this.emailServers = emailServers;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailServerListResponse emailServerListResponse = (EmailServerListResponse) o;
        return Objects.equals(this.emailServers, emailServerListResponse.emailServers);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(emailServers);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailServerListResponse {\n");
        sb.append("    emailServers: ").append(toIndentedString(emailServers)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
